#
# spec file for package msitools
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1_0-0

Name:           msitools
Version:        0.103
Release:        2.7
Summary:        Tools to inspect and build Windows Installer (.MSI) files
License:        GPL-2.0-or-later
URL:            https://wiki.gnome.org/msitools
Source:         https://download.gnome.org/sources/msitools/%{version}/%{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE msitools-set-explicit-bash.patch -- Set bash to be the explicit interpreter
Patch0:         msitools-set-explicit-bash.patch

BuildRequires:  bison
BuildRequires:  intltool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0) >= 2.14
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.9.4
BuildRequires:  pkgconfig(libgcab-1.0) >= 0.1.10
BuildRequires:  pkgconfig(libgsf-1)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.7
BuildRequires:  pkgconfig(vapigen) >= 0.16

%description
msitools is a set of programs to inspect and build Windows Installer
(.MSI) files.  It is based on libmsi, a portable library to read and
write .MSI files.

msitools plans to be a solution for packaging and deployment of
cross-compiled Windows applications.

%package -n libmsi-%{sover}
Summary:        Library to inspect and build Windows Installer (.MSI) files
License:        LGPL-2.1-or-later

%description -n libmsi-%{sover}
libmsi is a port of (and a subset of) Wine's implementation of the Windows
Installer.

%package -n typelib-1_0-Libmsi-1_0
Summary:        Introspection bindings for libmsi, a library to inspect and build .msi files
License:        LGPL-2.1-or-later

%description -n typelib-1_0-Libmsi-1_0
libmsi is a port of (and a subset of) Wine's implementation of the Windows
Installer.

%package devel
Summary:        Development files for libmsi, a library to inspect and build .msi files
License:        LGPL-2.1-or-later
Requires:       %{name} = %{version}
Requires:       libmsi-%{sover} = %{version}
Requires:       typelib-1_0-Libmsi-1_0 = %{version}

%description devel
msitools is a set of programs to inspect and build Windows Installer
(.MSI) files.  It is based on libmsi, a portable library to read and
write .MSI files.  libmsi in turn is a port of (and a subset of) Wine's
implementation of the Windows Installer.

msitools can be used for packaging and deployment of
cross-compiled Windows applications.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}

%ldconfig_scriptlets -n libmsi-%{sover}

%files
%license copyright
%doc AUTHORS NEWS README.md
%{_bindir}/msibuild
%{_bindir}/msidiff
%{_bindir}/msidump
%{_bindir}/msiextract
%{_bindir}/msiinfo
%{_bindir}/wixl
%{_bindir}/wixl-heat
%{_datadir}/bash-completion/completions/msitools
%{_datadir}/wixl-%{version}/

%files lang -f %{name}.lang

%files -n libmsi-%{sover}
%{_libdir}/libmsi-1.0.so.0*

%files -n typelib-1_0-Libmsi-1_0
%{_libdir}/girepository-1.0/Libmsi-1.0.typelib

%files devel
%{_includedir}/libmsi-1.0/
%{_libdir}/libmsi-1.0.so
%{_libdir}/pkgconfig/libmsi-1.0.pc
%{_datadir}/gir-1.0/*.gir
%{_datadir}/vala/vapi/

%changelog
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Tue Sep 19 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.103:
  + Renamed libmsi to libmsi-1.0
  + Change GUINT_FROM_LE to GUINT16_FROM_LE
  + Fedora 39 *.wxi fixes
  + Build fixes.
- Add sover define and set it to 1_0-0 following upstreams rename.
  Following this, the subpackage libmsi0 is renamed libmsi-1_0-0.
- Add msitools-set-explicit-bash.patch: Set bash to be the explicit
  interpreter
- Use ldconfig_scriptlets macro for post(un) handling.
* Tue Jun 20 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.102:
  + Minimal UI support
  + Support DefaultVersion and CompanionFile in File element
  + Handle AllowDowngrades and AllowSameVersionUpgrades in
    MajorUpgrade
  + Default Win64 to true on 64-bit arch
  + Support all CustomAction Execute types properly
  + Add sys.BUILDARCH preprocessor variable
  + Strip scheduling condition nodes
  + Add IniFile support
  + Remove default UI actions from
    AdminUISequence/InstallUISequence
  + Add support for ProgressText element
  + Various build fixes
  + Updated translations.
* Tue Feb  2 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.101:
  * convert the build system to Meson
  * remove uuid dependency
  * wixl: Make the ServiceControl attributes Remove/Start/Stop
    optional.
  * wixl: Implement SET_PROPERTY custom action
  * wixl: Properly handle empty GUID in Component nodes
  * wixl: Support ASYNC for CustomAction.Return
  * msiinfo: fix buffer overflow
  * translation updates, various misc fixes
* Tue Feb 18 2020 Martin Pluskal <mpluskal@suse.com>
- Modernise spec file
* Tue Nov 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.100:
  * fix v0.99 regression on big-endian systems
  * wixl: Support use of FileKey in CustomAction
  * wixl: support Arguments attribute in shortcuts
  * new wxi manifests for brotli, fribidi, libpsl, libunistring
  * update wxi manifests fo icu, readline, nettle, adwaita-icon-theme,
    gcc, OpenEXR, ilmbase
  * remove gtk-vnc manifest
  * translation updates, build-sys improvements
* Fri Feb 15 2019 Martin Hauke <mardnh@gmx.de>
- Update to version 0.99:
  * new wxi manifests for harfbuzz, icu, dlfcn, speex, wavpack, openexr,
    ilmbase, gcc-c++, gsm & libtheora
  * update libidn2 to 2.0.4
  * update libvirt to 5.0
  * update openssl to 1.1.0h
  * update spice-gtk to 0.36
  * make spice-gtk ship with GStreamer WASAPI plugin instead DirectSound
  * various dependencies wxi fixes
  * wixl: fix crash when Feature.Level isn't specified
  * fix rhbz#1629516 "string table load failed!" on some MSI
  * add check-wxi: validation of wxi files on Fedora
  * translation updates, build-sys improvements
* Fri Aug  3 2018 bjorn.lie@gmail.com
- Update to version 0.98:
  + Update gcc.wxi to 7.3.0.
  + Update glib2.wxi to 2.54.1.
  + Update expat.wxi to 2.2.4.
  + Update fontconfig.wxi to 2.12.6.
  + Update spice-glib.wxi to 0.35 and include gstvideo.
  + Update wxi form gstreamer1 commponents to 1.14.1 stable
    release.
  + Fix error on msiextract while opening empty cab files.
  + build-sys improvements.
  + Updated translations.
* Sun Feb 18 2018 jengelh@inai.de
- Update summaries, and let description say what it does now,
  not in the future.
* Fri Feb 16 2018 aloisio@gmx.com
- Update to version v0.97
  * fix potential crash in read_properties
  * fix double-frees in libmsi_summary_info_finalize
  * wixl-heat: escape $ in filename, bgo#756904
  * correctly parse dates, bgo#752860
  * msiextract: fix extracting to SourceDir, bgo#773935
  * wix updates: glib2, jasper, adwaita
  * translation updates, build-sys fixes
  version 0.96
  * Add libvirt-glib.wxi
  * Update nettle to 3.2.1
  * Fix implicit declaration of mkdir in the testdatabase
  * Disable -Wbad-function-cast (build-sys)
  * Removed unneeded workaround (build-sys)
  * Remove non-existent libvirt-glib translations
  * Fix translations's path for libvirt-glib
  * Add adwaita-icon-theme.wxi
  * Add pcre.wxi
  * Add pcre as glib2 dependency
  * Remove virt-host-validade (libvirt.wxi)
  * Update libspice-client-gtk dll version
  * Add support to external cab handling (msiextract)
  * Update adwaita and glib for f25
  * Update git.mk
  * Fix "make -j"
  * Update gstreamer1 to 1.10.0
  * Update gstreamer1-plugins-bad-free to 1.10.0
  * Drop spice-gtk.wxi (spice-gtk2)
  * Updade nettle to 3.3
  * Remove libidn's locale data
  * Translations
  version 0.95
  * Add libepoxy.wxi
  * Update gtk3.wxi
  * Update libcacad.wxi
  * Update nss.wxi
  * Update nspr.wxi
  * Update pango.wxi
  * Update gnutls.wxi
  * Update nettle.wxi
  * Update libvirt.wxi
  * Update fontconfig.wxi
  * Add bzip2.wxi
  * Update freetype.wxi
  * Update gstreamer1.wxi
  * Update gstreamer1-plugins-base.wxi
  * Update gstreamer1-plugins-bad-free.wxi
  * Translations
  version 0.94
  * Add support for Signature table
  * Add support for scheduling AppSearch
  * Add support for MsiFileHash table
  * Update libpng wxi
  * Add winpthreads wxi
  * Update libvirt wxi
  * Add opus wxi
  * Add spice-glib wxi
  * Update libffi wxi
  * Update glib2 wxi
  * Update libsoup wxi
  * Add sqlite
  * Update nettle wxi
  * Update gtk2 wxi
  * Update libgcrypt wxi
  * Add option to make packages win64-aware
  * Treat EDITTIME property as filetime in parse_prop
  * Add gtk3 wxi
  * Add spice-gtk3 wxi
  * Add gtk-vnc2 wxi
  * Add rest wxi
  * Add libgovirt wxi
  * Add gstreamer1 exi
  * Add gstreamer1-plugins-base wxi
  * Add gstreamer1-plugins-good wxi
  * Add gstreamer1-plugins-bad-free wxi
  * Update spice-glib wxi
  * Update gcc wxi
  * Fix wix close tag when no component groups are specified
    (wixl-heat)
  * Build clean-ups
  * Misc bug fixes
  * Translations
- Spec cleanup
* Wed Feb 22 2017 mpluskal@suse.com
- Cleanup spec file
* Wed Dec 10 2014 vuntz@opensuse.org
- Initial package (0.93)
